import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="build-dist-package",
    version="0.1.10",
    author="Meng yangyang",
    author_email="mengyy_linux@163.com",
    description="Fast build distribute package structure",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='MIT',
    url="https://github.com/hotbaby/build-dist-package",
    install_requires=["click>=7.0"],
    entry_points={
        'console_scripts': [
            'build-dist-package=build_dist_package.bin.build:cli'
        ]
    },
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 2",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)


#!/usr/bin/env python

import click
from build_dist_package import build_dist_package


@click.command()
@click.argument('pkg-name')
@click.option('--path', default='.', help='package path')
@click.option('--pkg-desc', default='A small example package', help='package short description')
@click.option('--pkg-url', default='https://github.com/pypa/sampleproject', help='package website url')
@click.option('--author', default='Example Author', help='author')
@click.option('--author-email', default='author@example.com', help='author email address')
def cli(pkg_name, path, pkg_desc, pkg_url, author, author_email):
    build_dist_package(pkg_name, path=path, pkg_desc=pkg_desc, pkg_url=pkg_url,
                       author=author, author_email=author_email)

